function ybkf = bkfilter(y,p,q,k)
% Passes a time series contained in the vector y through the Baxter-King
% filter, where p is the period of the shortest cycle passed, q is the
% period of the longest cycle passes, and k is the truncation point. The
% first and last k elements of the output vector ybkf will equal zero, so
% that the dates corresponding to each row of the input and output vectors
% remain the same.
%
% Program written for MATLAB 8.3 (R2014a) by Peter Ireland, Department
% of Economics, Boston College (peter.ireland@bc.edu).

% =========================================================================

T = length(y);

omegah = 2*pi/p;
omegal = 2*pi/q;

alphavec = zeros(1,2*k+1);

alphavec(k+1) = (omegah-omegal)/pi;

for h = 1:k
    
    alphavec(k+1+h) = (sin(h*omegah)-sin(h*omegal))/(h*pi);
    alphavec(k+1-h) = alphavec(k+1+h);
    
end

theta = -sum(alphavec,2)/(2*k+1);

alphavec = alphavec+theta;

ybkf = zeros(T-2*k,1);

for t = 1:T-2*k
    
    ybkf(t) = alphavec*y(t:t+2*k);
    
end

ybkf = [ zeros(k,1) ; ybkf ; zeros(k,1) ];



