function cllfn6 = cllfn6(bvec)
% Evaluates the concentrated log likelihood function for a six-variable
% structural VAR for output, prices, interest rates, Divisia money, the
% user cost of money, and commodity prices. One of two identification
% schemes can be chosen in svarest6.m:
% 
%   model 1 = Cholesky identification scheme
%   model 2 = Interest rate-money rule
%
% Note: to avoid numerical problems associated with parameter values of
% different orders of magnitude, the likelihood is parameterized here in
% terms of B = SIGMA\A.
%
% Program written for MATLAB 8.3 (R2014a) by Peter Ireland, Department
% of Economics, Boston College (peter.ireland@bc.edu).
%
% =========================================================================

global model Omegahat T

if model == 1
    
    B = [ abs(bvec(16)) 0 0 0 0 0 ; ...
          bvec(1) abs(bvec(17)) 0 0 0 0 ; ...
          bvec(2) bvec(3) abs(bvec(18)) 0 0 bvec(4) ; ...
          bvec(5) bvec(6) bvec(7) abs(bvec(19)) 0 bvec(8) ; ...
          bvec(9) bvec(10) bvec(11) bvec(12) abs(bvec(20)) bvec(13) ; ...
          bvec(14) bvec(15) 0 0 0 abs(bvec(21)) ];
    
else
    
    B = [ abs(bvec(12)) 0 0 0 0 0 ; ...
          bvec(1) abs(bvec(13)) 0 0 0 0 ; ...
          0 0 abs(bvec(14)) bvec(2) 0 0 ; ...
          -abs(bvec(15)) bvec(3) 0 abs(bvec(15)) bvec(4) 0 ; ...
          -bvec(6) 0 bvec(5) bvec(6) abs(bvec(16)) 0 ; ...
          bvec(7) bvec(8) bvec(9) bvec(10) bvec(11) abs(bvec(17)) ];
      
end

cllfn6 = (T/2)*(6*log(2*pi)-log(det(B)^2)+trace((B'*B)*Omegahat));
