function [ pimp,yimp,rimp,mimp,uimp,cimp ] = imps(Gamma,A,Sigma,shockno)
% Computes impulse responses for prices, output, the interest rate, money,
% the user cost of money, and commodity prices to
%
%       shockno = 1 - prices
%       shockno = 2 - output
%       shockno = 3 - the interest rate (monetary policy)
%       shockno = 4 - money (money demand)
%       shockno = 5 - the user cost of money (the monetary system)
%       shockno = 6 - commodity prices
%
% Program written for MATLAB 8.3 (R2014a) by Peter Ireland, Department
% of Economics, Boston College (peter.ireland@bc.edu).
%
% =========================================================================


global level q
    
Xtvec = zeros(6*q,41);

epsvec = zeros(6,1);
epsvec(shockno) = 1;

Xtvec(1:6,2) = (A\Sigma)*epsvec;

for j = 3:41
    
    Xtvec(:,j) = Gamma*Xtvec(:,j-1);
    
end

if level

    pimp = Xtvec(1,:)';
    yimp = Xtvec(2,:)';
    rimp = Xtvec(3,:)';
    mimp = Xtvec(4,:)';
    uimp = Xtvec(5,:)';
    cimp = Xtvec(6,:)';
    
else
    
    pimp = cumsum(Xtvec(1,:)');
    yimp = cumsum(Xtvec(2,:)');
    rimp = Xtvec(3,:)';
    mimp = cumsum(Xtvec(4,:)');
    uimp = Xtvec(5,:)';
    cimp = cumsum(Xtvec(6,:)');
    
end