function [ pdecomp,ydecomp,rdecomp,mdecomp,udecomp,cdecomp ] = vardecomp(Gamma,A,Sigma,kvec,shockno)
% Computes the percentage of the k-quarter-ahead forecast error variances
% in prices, output, the interest rate, money, the user cost of money, and
% commodity prices to to
%
%       shockno = 1 - prices
%       shockno = 2 - output
%       shockno = 3 - the interest rate (monetary policy)
%       shockno = 4 - money (money demand)
%       shockno = 5 - the user cost of money (the monetary system)
%       shockno = 6 - commodity prices

% for values of k given in the vector kvec.
%
% Program written for MATLAB 8.3 (R2014a) by Peter Ireland, Department
% of Economics, Boston College (peter.ireland@bc.edu).
%
% =========================================================================

global level q

AinvSig = [ A\Sigma ; zeros(6*(q-1),6) ];

Vtot = eye(6);
Vshock = zeros(6,6);
Vshock(shockno,shockno) = 1;

varpshock = zeros(20,1);
varyshock = zeros(20,1);
varrshock = zeros(20,1);
varmshock = zeros(20,1);
varushock = zeros(20,1);
varcshock = zeros(20,1);

if level
    
    Sigktot = zeros(6*q,6*q);
    Sigkshock = zeros(6*q,6*q);

    Gammak = eye(6*q);

    for k = 1:20
    
        Sigktot = Sigktot + Gammak*AinvSig*Vtot*AinvSig'*Gammak';
    
        Sigkshock = Sigkshock + Gammak*AinvSig*Vshock*AinvSig'*Gammak';
    
        varpshock(k) = 100*Sigkshock(1,1)/Sigktot(1,1);
    
        varyshock(k) = 100*Sigkshock(2,2)/Sigktot(2,2);
    
        varrshock(k) = 100*Sigkshock(3,3)/Sigktot(3,3);
    
        varmshock(k) = 100*Sigkshock(4,4)/Sigktot(4,4);
    
        varushock(k) = 100*Sigkshock(5,5)/Sigktot(5,5);
    
        varcshock(k) = 100*Sigkshock(6,6)/Sigktot(6,6);
    
        Gammak = Gammak*Gamma;
    
    end
    
else
    
    lSigktot = zeros(6*q,6*q);
    lSigkshock = zeros(6*q,6*q);
    
    gSigktot = zeros(6*q,6*q);
    gSigkshock = zeros(6*q,6*q);

    lGammak = eye(6*q);
    gGammak = eye(6*q);

    for k = 1:20
    
        lSigktot = lSigktot + lGammak*AinvSig*Vtot*AinvSig'*lGammak';
    
        lSigkshock = lSigkshock + lGammak*AinvSig*Vshock*AinvSig'*lGammak';
        
        gSigktot = gSigktot + gGammak*AinvSig*Vtot*AinvSig'*gGammak';
    
        gSigkshock = gSigkshock + gGammak*AinvSig*Vshock*AinvSig'*gGammak';
            
        varpshock(k) = 100*gSigkshock(1,1)/gSigktot(1,1);
    
        varyshock(k) = 100*gSigkshock(2,2)/gSigktot(2,2);
    
        varrshock(k) = 100*lSigkshock(3,3)/lSigktot(3,3);
    
        varmshock(k) = 100*gSigkshock(4,4)/gSigktot(4,4);
    
        varushock(k) = 100*lSigkshock(5,5)/lSigktot(5,5);
    
        varcshock(k) = 100*gSigkshock(6,6)/gSigktot(6,6);
    
        lGammak = lGammak*Gamma;
        
        gGammak = gGammak + lGammak;
    
    end
    
end

pdecomp = varpshock(kvec);
ydecomp = varyshock(kvec);
rdecomp = varrshock(kvec);
mdecomp = varmshock(kvec);
udecomp = varushock(kvec);
cdecomp = varcshock(kvec);
