% ypmcors.com: Computes correlations between output and money and prices
% and money at various leads and lags.
%
% Options:
%
%       level = 1 for data in BP filtered log levels
%       level = 0 for data in growth rates
%
%       sample = 0 for 1967:1 - 2013:4 subsample
%       sample = 1 for 1967:1 - 1983:4 subsample
%       sample = 2 for 1984:1 - 1999:4 subsample
%       sample = 3 for 2000:1 - 2013:4 subsample
%
% Program written for MATLAB 8.3 (R2014a) by Peter Ireland, Department
% of Economics, Boston College (peter.ireland@bc.edu).
%
% =========================================================================
% =========================================================================

% =========================================================================
% Select filtered log levels or growth rates and sample period. Load and
% filter data.
% =========================================================================

level = 1;
sample = 1;

if sample == 0
    
    Tstart = 1;
    Tend = 188;
    
elseif sample == 1
    
    Tstart = 1;
    Tend = 68;
    
elseif sample == 2
    
    Tstart = 69;
    Tend = 132;
    
else
    
    Tstart = 133;
    Tend = 188;
    
end
    
T = Tend - Tstart + 1;

load pyr.dat
load ssm.dat
load divm.dat

p = pyr(:,1);
y = pyr(:,2);

ssm1 = ssm(:,1);
ssm2 = ssm(:,2);
ssmzm = ssm(:,3);

divm1 = divm(:,1);
divm2 = divm(:,2);
divmzm = divm(:,3);

if level == 1

    pf = bkfilter(p,6,32,12);
    yf = bkfilter(y,6,32,12);
    ssm1f = bkfilter(ssm1,6,32,12);
    divm1f = bkfilter(divm1,6,32,12);
    ssm2f = bkfilter(ssm2,6,32,12);
    divm2f = bkfilter(divm2,6,32,12);
    ssmzmf = bkfilter(ssmzm,6,32,12);
    divmzmf = bkfilter(divmzm,6,32,12);

    if (Tstart == 1) && (Tend < 188)
         Tstart = Tstart + 12;
        T = T - 12;
    end

    if (Tstart > 1) && (Tend == 188)
        Tend = Tend - 12;
        T = T - 12;
    end

    if (Tstart == 1) && (Tend == 188)
        Tstart = Tstart + 12;
        Tend = Tend - 12;
        T = T - 24;
    end
    
else

    pf = [ 0 ; p(2:188) - p(1:187) ];
    yf = [ 0 ; y(2:188) - y(1:187) ];
    ssm1f = [ 0 ; ssm1(2:188) - ssm1(1:187) ];
    divm1f = [ 0 ; divm1(2:188) - divm1(1:187) ];
    ssm2f = [ 0 ; ssm2(2:188) - ssm2(1:187) ];
    divm2f = [ 0 ; divm2(2:188) - divm2(1:187) ];
    ssmzmf = [ 0 ; ssmzm(2:188) - ssmzm(1:187) ];
    divmzmf = [ 0 ; divmzm(2:188) - divmzm(1:187) ];

    if Tstart == 1
        Tstart = Tstart + 1;
        T = T - 1;
    end
    
end

pf = pf(Tstart:Tend);
yf = yf(Tstart:Tend);
ssm1f = ssm1f(Tstart:Tend);
divm1f = divm1f(Tstart:Tend);
ssm2f = ssm2f(Tstart:Tend);
divm2f = divm2f(Tstart:Tend);
ssmzmf = ssmzmf(Tstart:Tend);
divmzmf = divmzmf(Tstart:Tend);

% =========================================================================
% compute correlations with real GDP
% =========================================================================

ycormat = zeros(6,33);

for j = -16:1:-1  
    
    cormat = corrcoef(ssm1f(1:T+j),yf(1-j:T));
    ycormat(1,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm1f(1:T+j),yf(1-j:T));
    ycormat(2,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssm2f(1:T+j),yf(1-j:T));
    ycormat(3,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm2f(1:T+j),yf(1-j:T));
    ycormat(4,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssmzmf(1:T+j),yf(1-j:T));
    ycormat(5,j+17) = cormat(1,2);
    
    cormat = corrcoef(divmzmf(1:T+j),yf(1-j:T));
    ycormat(6,j+17) = cormat(1,2);
    
end

for j = 0:16
    
    cormat = corrcoef(ssm1f(j+1:T),yf(1:T-j));
    ycormat(1,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm1f(j+1:T),yf(1:T-j));
    ycormat(2,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssm2f(j+1:T),yf(1:T-j));
    ycormat(3,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm2f(j+1:T),yf(1:T-j));
    ycormat(4,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssmzmf(j+1:T),yf(1:T-j));
    ycormat(5,j+17) = cormat(1,2);
    
    cormat = corrcoef(divmzmf(j+1:T),yf(1:T-j));
    ycormat(6,j+17) = cormat(1,2);
    
end

% =========================================================================
% compute correlations with GDP deflator
% =========================================================================

pcormat = zeros(6,33);

for j = -16:1:-1  
    
    cormat = corrcoef(ssm1f(1:T+j),pf(1-j:T));
    pcormat(1,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm1f(1:T+j),pf(1-j:T));
    pcormat(2,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssm2f(1:T+j),pf(1-j:T));
    pcormat(3,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm2f(1:T+j),pf(1-j:T));
    pcormat(4,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssmzmf(1:T+j),pf(1-j:T));
    pcormat(5,j+17) = cormat(1,2);
    
    cormat = corrcoef(divmzmf(1:T+j),pf(1-j:T));
    pcormat(6,j+17) = cormat(1,2);
    
end

for j = 0:16
    
    cormat = corrcoef(ssm1f(j+1:T),pf(1:T-j));
    pcormat(1,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm1f(j+1:T),pf(1:T-j));
    pcormat(2,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssm2f(j+1:T),pf(1:T-j));
    pcormat(3,j+17) = cormat(1,2);
    
    cormat = corrcoef(divm2f(j+1:T),pf(1:T-j));
    pcormat(4,j+17) = cormat(1,2);
    
    cormat = corrcoef(ssmzmf(j+1:T),pf(1:T-j));
    pcormat(5,j+17) = cormat(1,2);
    
    cormat = corrcoef(divmzmf(j+1:T),pf(1:T-j));
    pcormat(6,j+17) = cormat(1,2);
    
end

% =========================================================================
% Report results.
% =========================================================================

fprintf('\r')
fprintf('Correlation of Y(t) and SSM1(t-k), k = 16 - 0: \r\r');
disp(ycormat(1,1:17));
fprintf('\r')
fprintf('Correlation of Y(t) and DIVM1(t-k), k = 16 - 0: \r\r');
disp(ycormat(2,1:17));
fprintf('\r')
fprintf('Correlation of Y(t) and SSM2(t-k), k = 16 - 0: \r\r');
disp(ycormat(3,1:17));
fprintf('\r')
fprintf('Correlation of Y(t) and DIVM2(t-k), k = 16 - 0: \r\r');
disp(ycormat(4,1:17));
fprintf('\r')
fprintf('Correlation of Y(t) and SSMZM(t-k), k = 16 - 0: \r\r');
disp(ycormat(5,1:17));
fprintf('\r')
fprintf('Correlation of Y(t) and DIVMZM(t-k), k = 16 - 0: \r\r');
disp(ycormat(6,1:17));
fprintf('\r')
fprintf('Correlation of P(t) and SSM1(t-k), k = 16 - 0: \r\r');
disp(pcormat(1,1:17));
fprintf('\r')
fprintf('Correlation of P(t) and DIVM1(t-k), k = 16 - 0: \r\r');
disp(pcormat(2,1:17));
fprintf('\r')
fprintf('Correlation of P(t) and SSM2(t-k), k = 16 - 0: \r\r');
disp(pcormat(3,1:17));
fprintf('\r')
fprintf('Correlation of P(t) and DIVM2(t-k), k = 16 - 0: \r\r');
disp(pcormat(4,1:17));
fprintf('\r')
fprintf('Correlation of P(t) and SSMZM(t-k), k = 16 - 0: \r\r');
disp(pcormat(5,1:17));
fprintf('\r')
fprintf('Correlation of P(t) and DIVMZM(t-k), k = 16 - 0: \r\r');
disp(pcormat(6,1:17));

